@@ -149,6 +149,12 @@ struct Dstutter : public Unit {
     float m_value;
 };
 
+struct Ddup : public Unit {
+    double m_repeats;
+    double m_repeatCount;
+    float m_value;
+};
+
 struct Dpoll : public Unit {
     char* m_id_string;
     bool m_mayprint;
@@ -241,6 +247,9 @@ void Dswitch_next(Dswitch* unit, int inNumSamples);
 void Dstutter_Ctor(Dstutter* unit);
 void Dstutter_next(Dstutter* unit, int inNumSamples);
 
+void Ddup_Ctor(Ddup* unit);
+void Ddup_next(Ddup* unit, int inNumSamples);
+
 void Dpoll_Ctor(Dpoll* unit);
 void Dpoll_Ctor(Dpoll* unit);
 void Dpoll_next(Dpoll* unit, int inNumSamples);
@@ -1971,6 +1980,39 @@ void Dstutter_Ctor(Dstutter* unit) {
     OUT0(0) = 0.f;
 }
 
+void Ddup_next(Ddup* unit, int inNumSamples) {
+    if (inNumSamples) {
+        if (unit->m_repeatCount >= unit->m_repeats) {
+            float val = DEMANDINPUT_A(1, inNumSamples);
+            float repeats = DEMANDINPUT_A(0, inNumSamples);
+
+            if (sc_isnan(repeats) || sc_isnan(val)) {
+                OUT0(0) = NAN;
+                return;
+            } else {
+                unit->m_value = val;
+                unit->m_repeats = floor(repeats + 0.5f);
+                unit->m_repeatCount = 0.f;
+            }
+        }
+
+        OUT0(0) = unit->m_value;
+        unit->m_repeatCount++;
+
+    } else {
+        unit->m_repeats = -1.f;
+        unit->m_repeatCount = 0.f;
+        RESETINPUT(0);
+        RESETINPUT(1);
+    }
+}
+
+void Ddup_Ctor(Ddup* unit) {
+    SETCALC(Ddup_next);
+    Ddup_next(unit, 0);
+    OUT0(0) = 0.f;
+}
+
 //////////////////////////////
 
 void Dconst_next(Dconst* unit, int inNumSamples) {
@@ -2314,6 +2356,7 @@ PluginLoad(Demand) {
     DefineSimpleUnit(Dswitch1);
     DefineSimpleUnit(Dswitch);
     DefineSimpleUnit(Dstutter);
+    DefineSimpleUnit(Ddup);
     DefineSimpleUnit(Dconst);
     DefineSimpleUnit(Dreset);
     DefineDtorUnit(Dpoll);
