@@ -360,7 +360,7 @@ void PV_MagSmear_next(PV_MagSmear* unit, int inNumSamples) {
 void PV_MagSmear_Ctor(PV_MagSmear* unit) {
     SETCALC(PV_MagSmear_next);
     ZOUT0(0) = ZIN0(0);
-    unit->m_tempbuf = 0;
+    unit->m_tempbuf = nullptr;
 }
 
 void PV_MagSmear_Dtor(PV_MagSmear* unit) { RTFree(unit->mWorld, unit->m_tempbuf); }
@@ -413,7 +413,7 @@ void PV_BinShift_next(PV_BinShift* unit, int inNumSamples) {
 void PV_BinShift_Ctor(PV_BinShift* unit) {
     SETCALC(PV_BinShift_next);
     ZOUT0(0) = ZIN0(0);
-    unit->m_tempbuf = 0;
+    unit->m_tempbuf = nullptr;
 }
 
 void PV_BinShift_Dtor(PV_BinShift* unit) { RTFree(unit->mWorld, unit->m_tempbuf); }
@@ -451,7 +451,7 @@ void PV_MagShift_next(PV_MagShift* unit, int inNumSamples) {
 void PV_MagShift_Ctor(PV_MagShift* unit) {
     SETCALC(PV_MagShift_next);
     ZOUT0(0) = ZIN0(0);
-    unit->m_tempbuf = 0;
+    unit->m_tempbuf = nullptr;
 }
 
 void PV_MagShift_Dtor(PV_MagShift* unit) { RTFree(unit->mWorld, unit->m_tempbuf); }
@@ -979,7 +979,7 @@ void PV_RandComb_next(PV_RandComb* unit, int inNumSamples) {
 void PV_RandComb_Ctor(PV_RandComb* unit) {
     SETCALC(PV_RandComb_next);
     ZOUT0(0) = ZIN0(0);
-    unit->m_ordering = 0;
+    unit->m_ordering = nullptr;
     unit->m_prevtrig = 0.f;
     unit->m_triggered = false;
 }
@@ -1039,7 +1039,7 @@ void PV_RandWipe_next(PV_RandWipe* unit, int inNumSamples) {
 void PV_RandWipe_Ctor(PV_RandWipe* unit) {
     SETCALC(PV_RandWipe_next);
     ZOUT0(0) = ZIN0(0);
-    unit->m_ordering = 0;
+    unit->m_ordering = nullptr;
     unit->m_prevtrig = 0.f;
     unit->m_triggered = false;
 }
@@ -1089,7 +1089,7 @@ void PV_Diffuser_next(PV_Diffuser* unit, int inNumSamples) {
 void PV_Diffuser_Ctor(PV_Diffuser* unit) {
     SETCALC(PV_Diffuser_next);
     ZOUT0(0) = ZIN0(0);
-    unit->m_shift = 0;
+    unit->m_shift = nullptr;
     unit->m_prevtrig = 0.f;
     unit->m_triggered = false;
 }
@@ -1135,7 +1135,7 @@ void PV_MagFreeze_next(PV_MagFreeze* unit, int inNumSamples) {
 void PV_MagFreeze_Ctor(PV_MagFreeze* unit) {
     SETCALC(PV_MagFreeze_next);
     ZOUT0(0) = ZIN0(0);
-    unit->m_mags = 0;
+    unit->m_mags = nullptr;
 }
 
 void PV_MagFreeze_Dtor(PV_MagFreeze* unit) { RTFree(unit->mWorld, unit->m_mags); }
@@ -1215,10 +1215,10 @@ void PV_BinScramble_next(PV_BinScramble* unit, int inNumSamples) {
 void PV_BinScramble_Ctor(PV_BinScramble* unit) {
     SETCALC(PV_BinScramble_next);
     ZOUT0(0) = ZIN0(0);
-    unit->m_to = 0;
+    unit->m_to = nullptr;
     unit->m_prevtrig = 0.f;
     unit->m_triggered = false;
-    unit->m_tempbuf = 0;
+    unit->m_tempbuf = nullptr;
 }
 
 void PV_BinScramble_Dtor(PV_BinScramble* unit) {
